import { Injectable } from '@nestjs/common';
import { PrismaService } from 'src/prisma.service';
import { CreateCategoryDto } from './dto/create-category.dto';
import { UpdateCategoryDto } from './dto/update-category.dto';
import { plainToClass } from 'class-transformer';
import { CategoryEntity } from './entities/category.entity';

@Injectable()
export class CategoriesService {
  constructor(private prisma: PrismaService) {}

  async create(createCategoryDto: CreateCategoryDto) {
    const category = plainToClass(CategoryEntity, createCategoryDto);
    return await this.prisma.category.create({
      data: category,
    });
  }

  async findAll() {
    return await this.prisma.category.findMany();
  }

  async findOne(id: string) {
    return await this.prisma.category.findUnique({
      where: {
        id,
      },
    });
  }

  async update(id: string, updateCategoryDto: UpdateCategoryDto) {
    const updatedCategory = {
      ...await this.findOne(id),
      ...plainToClass(CategoryEntity, updateCategoryDto),
    };
    return await this.prisma.category.update({
      where: {
        id,
      },
      data: {
        ...updatedCategory,
      },
    });
  }

  async remove(id: string) {
    return await this.prisma.category.update({
      where: {
        id,
      },
      data: {
        deletedAt: new Date(),
      },
    });
  }
}
