import {
  Controller,
  Get,
  Post,
  Body,
  Patch,
  Param,
  Delete,
} from '@nestjs/common';
import { ApiTags } from '@nestjs/swagger';
import { DirectorsService } from './directors.service';
import { CreateDirectorDto } from './dto/create-director.dto';
import { UpdateDirectorDto } from './dto/update-director.dto';

@ApiTags('directors')
@Controller('director')
export class DirectorsController {
  constructor(private readonly directorsService: DirectorsService) {}

  @Post()
  async create(@Body() createDirectorDto: CreateDirectorDto) {
    return await this.directorsService.create(createDirectorDto);
  }

  @Get()
  async findAll() {
    return await this.directorsService.findAll();
  }

  @Get(':id')
  async findOne(@Param('id') id: string) {
    return await this.directorsService.findOne(id);
  }

  @Patch(':id')
  async update(@Param('id') id: string, @Body() updateDirectorDto: UpdateDirectorDto) {
    return await this.directorsService.update(id, updateDirectorDto);
  }

  @Delete(':id')
  async remove(@Param('id') id: string) {
    return await this.directorsService.remove(id);
  }
}
